@@ -5,7 +5,7 @@ from abc import ABC, abstractmethod
 import numpy as np
 import pandas as pd
 
-from .numerics import optimized_portfolio_on_sharperatio, optimized_portfolio_mpt_costfunction
+from .numerics import optimized_portfolio_on_sharperatio, optimized_portfolio_mpt_costfunction, optimized_portfolio_mpt_entropy_costfunction
 
 
 class OptimizedWeightingPolicy(ABC):
@@ -170,3 +170,54 @@ class OptimizedWeightingPolicyUsingMPTCostFunction(OptimizedWeightingPolicy):
         summary['V0'] = self.V0
         summary['lamb'] = self.lamb
         return summary
+
+
+class OptimizedWeightingPolicyUsingMPTEntropyCostFunction(OptimizedWeightingPolicy):
+    def __init__(self, rf, r=None, cov=None, symbols=None, lamb0=None, lamb1=None, V=10.0):
+        super(OptimizedWeightingPolicyUsingMPTEntropyCostFunction, self).__init__(rf, r=r, cov=cov, symbols=symbols)
+        self.lamb0 = lamb0
+        self.lamb1 = lamb1
+        self.V = V
+
+        if r is not None and cov is not None:
+            self.optimize(r, cov, symbols=symbols)
+
+    def optimize(self, r, cov, symbols=None):
+        super(OptimizedWeightingPolicyUsingMPTEntropyCostFunction, self).optimize(r, cov, symbols=symbols)
+        self.optimized_sol = optimized_portfolio_mpt_entropy_costfunction(r, cov, self.rf, self.lamb0, self.lamb1, V=self.V)
+        self.optimized = True
+
+        self.optimized_unnormalized_weights = self.optimized_sol.x
+        self.optimized_weights = self.optimized_unnormalized_weights[:-1] / np.sum(self.optimized_unnormalized_weights[:-1])
+        self.optimized_costfunction = -self.optimized_sol.fun
+        self.optimized_portfolio_yield = np.sum(self.optimized_weights * self.r)
+        sqweights = np.matmul(
+            np.expand_dims(self.optimized_weights, axis=1),
+            np.expand_dims(self.optimized_weights, axis=0)
+        )
+        self.optimized_volatility = np.sqrt(np.sum(sqweights * self.cov))
+
+    @property
+    def weights(self):
+        return self.optimized_weights
+
+    @property
+    def portfolio_yield(self):
+        return self.optimized_portfolio_yield
+
+    @property
+    def volatility(self):
+        return self.optimized_volatility
+
+    @property
+    def mpt_entropy_costfunction(self):
+        return self.optimized_costfunction
+
+    @property
+    def portfolio_summary(self):
+        summary = super(OptimizedWeightingPolicyUsingMPTEntropyCostFunction, self).portfolio_summary
+        summary['mpt_entropy_costfunction'] = self.mpt_entropy_costfunction
+        summary['V'] = self.V
+        summary['lamb0'] = self.lamb0
+        summary['lamb1'] = self.lamb1
+        return summary
